初恋这件小事 (豆瓣)
Description: 初恋这件小事电影简介和剧情介绍,初恋这件小事影评、图片、预告片、影讯、论坛、在线购票
Keywords: 初恋这件小事,สิ่งเล็กเล็กที่เรียกว่า...รัก,初恋这件小事影评,剧情介绍,电影图片,预告片,影讯,在线购票,论坛

No.209豆瓣电影Top250

# 初恋这件小事 สิ่งเล็กเล็กที่เรียกว่า...รัก (2010)

导演: 普特鹏·普罗萨卡·那·萨克那卡林 / 华森·波克彭
编剧: 普特鹏·普罗萨卡·那·萨克那卡林
主演: 平采娜·乐维瑟派布恩 / 马里奥·毛瑞尔 / 苏达拉·布查蓬 / 雅尼卡·桑普蕾舞 / 诺特·阿查拉那·阿瑞亚卫考 / 皮拉瓦特·赫拉巴特 / 普特鹏·普罗萨卡·那·萨克那卡林 / 华森·波克彭
类型: 剧情 / 喜剧 / 爱情
官方网站: sahamongkolfilm.com/saha-movie/crazy-little-thing-called-love-movie-2553/
制片国家/地区: 泰国
语言: 泰语 / 印度尼西亚语 / 英语
上映日期: 2012-06-05(中国大陆) / 2010-08-12(泰国)
片长: 118分钟(泰国) / 100分钟(中国大陆)
又名: 初恋那件小事(港) / 暗恋那点小事 / 叫做爱的小事 / Sing lek lek tee reak wa rak / A Little Thing Called Love / First Love
IMDb: tt1859438
豆瓣评分
引用
8.5
945743人评价
5星
41.7%
4星
41.9%
3星
14.8%
2星
1.3%
1星
0.3%
好于 97% 爱情片
好于 98% 喜剧片
想看 看过
评价:
推荐

## 初恋这件小事的剧情简介 · · · · · ·

初中生小水相貌平平，家境一般，所以在学校里并不受重视。但是她心地善良，又有一群死党，日子过得倒也开心。某天，她遇见了帅气的学长阿亮（马里奥·毛瑞尔 Mario Maurer 饰），春心萌动，无 法遏制。她喜欢看他踢足球，看他拍照，如痴如狂。上英语课时，她不停地给死党传纸条 表达对阿亮的爱慕。然而，英语老师则指出她除了英语一无是处。回到家，叔叔从美国捎来了父亲的消息，说如果她能考全校第一，就可以去美国。于是，她按下决心要努力加油。某天，小水等人在买饮料时，碰到篮球队员蛮横插队。阿亮挺身而出，为她们教训了对方，并挨了校长的责骂。小水也第一次听说，阿亮的父亲因为射失点球而退役的事情，理解了他心中的隐痛。由于舞蹈队是给美女准备的，所以小水等一干姐妹准备在话剧社大展身手，没想到学长也来到这个社团。两人还扮演王子公主，他们的恋情会由此展开么？…… ©豆瓣

## 初恋这件小事的演职员 · · · · · · ( 全部 12 )

- 普特鹏·普罗萨卡·那·萨克那卡林 导演
- 华森·波克彭 导演
- 平采娜·乐维瑟派布恩 饰 小水 Nam
- 马里奥·毛瑞尔 饰 阿亮 Shone
- 苏达拉·布查蓬 饰 小茵老师 Teacher Pon
- 雅尼卡·桑普蕾舞 饰 小菲(芒果蛋糕妹) Faye

## 初恋这件小事的视频和图片 · · · · · · ( 预告片2 | 视频评论1 · 添加 | 图片1236 · 添加 )

## 喜欢这部电影的人也喜欢 · · · · · ·

  罗马假日

  恋恋笔记本

  泰坦尼克号

  爱在黎明破晓前

  傲慢与偏见

  剪刀手爱德华

  重庆森林

  真爱至上

  天使爱美丽

  怦然心动

我要写短评

## 初恋这件小事的短评 · · · · · · ( 全部 229782 条 )

热门 / 最新 / 好友

### 4598 有用 六兔 看过 2010-12-02 10:24:53

一场强大的暗恋背后其实还有另外一场相反的暗恋

### 6921 有用 Dululu 看过 2010-12-04 22:08:49

结局真多余。。。。。。。。

### 3508 有用 米哑， 看过 2010-12-02 21:39:01

你有几个最佳损友，她们陪你分享你心里的小秘密。你在初中小心翼翼的喜欢一个男孩子，你收集关于他的一切消息，你在你们共同上学需要走的小巷口左顾右盼，你记住他的每一句话，你为他做了让自己可以变得更好更美的所有事情，那些好长好长的岁月里你只是想让他看你一眼而已。

### 3210 有用 要早睡啊minami 看过 2010-11-30 01:48:42

要不是这狗血的结尾我会打五星的！最让我感动的反而不是初恋了，是这群丑小鸭之间的友谊，让我想起我初中时候的那群小姐妹，“朱古力跳跳队”——谢十三、吴玲、杨秀丽、徐星云、拉链、吴美，还有我，一共七个，傻妞！十二万分怀念那个时候的我们……向青春致敬！

### 2637 有用 玛琦 看过 2010-12-10 16:51:16

游泳池那段哭得我稀里哗啦 现实生活到那里就结束了

> 更多短评 229782条
为什么被折叠？ 有一些短评被折叠了
评论被折叠，是因为发布这条评论的帐号行为异常。评论仍可以被展开阅读，对发布人的账号不造成其他影响。如果认为有问题，可以联系豆瓣电影。
你关注的人还没写过短评
我要写影评

## 初恋这件小事的影评 · · · · · · ( 全部 4441 条 )

热门 / 最新 / 好友
六兔 2010-12-02 11:15:04

## 我把青春耗在暗恋里

青春本来就是是一件乐在其中却不知情，离开了满是感伤，回想起来又满是想法的事情。 对于泰国的青春片我承认我一点抵抗力都没有。 《初恋这件小事》在很多人的并不期待中汹涌袭来，校园味的海报，言情味的名字，多数人以为会是并不起眼的片子。好的电影能触动人心，当开... (展开)
5594 123 730回应 收起
Sophie Z 2010-12-17 02:55:59

## 狗血的青春，我们都有过

14岁那年我暗恋初中班里的学委，那个很瘦很高的眼镜男，数学好得一塌糊涂，总是看各种各样的小说。 那时他和班里的副班长MM形影不离，他们总能一起被叫到老师办公室去，一起布置黑板报，一起去领奖状之类的东西。如果那年就出现了四娘，我想我也会写出，“我在一个你看不到的角... (展开)
1913 36 278回应 收起
allyshine 2010-11-29 18:21:58

## 在 “初戀這件小事” 裡我也做過的事

这篇影评可能有剧透

這部電影講的是每個人的故事，那我也來數數我做過的吧： 1. 故意約朋友去某個地方，為的就是偷看他 2. 和朋友在上課時傳紙條討論他的事 3. 裝做沒事的故意經過他身旁 4. 把一件屬於他的但基本上算是垃圾的東西，當作珍藏並常常對著這件物品說話 5. 打他家電話，然後裝作... (展开)
632 22 185回应 收起
J 2010-11-29 08:21:51

## 暗恋这件小事

这篇影评可能有剧透

多谢copen的字幕 等这部电影等了好久好久。最初寻找此片的动力是Mario但是后来被剧情深深的吸引，一直痴痴地等了3个月。 名字叫做初恋这件小事， 其实我觉得不如叫暗恋这件小事，毕竟两人那时并没有在一起。暂且我不去夸这部戏的剧情不去夸这部戏主角们的演技，相信看过的人都... (展开)
556 25 143回应 收起
饺大仙 2010-12-04 13:39:44

## 此片满足了所有初中以下的少女幻想

这篇影评可能有剧透

老实说此片得分如此之高一定得归功于女性同胞的鼎力相助。 另外就要仰仗Mario那张俊俏而粉嫩的脸蛋。 貌似从《暹罗之恋》开始，泰国俨然一副文艺小清新后起之秀的阵仗。我也不得不承认它对明朗的色调和文艺角度的空镜头把握非常精准到位。 另外一点跟日本台湾一样，它的小清新... (展开)
419 75 164回应 收起
男娼起义 2010-12-08 16:48:44

## TEENAGE DREAM

手上青春还剩多少？数数已经换过几个对象了？让我一个“老头子”也会想起去写一场少女的春梦了，肯定带着羡慕， 你当不成那个怀春的少女，更当不成少女爱慕的那个对象，甚至想以一个旁观者去参与下，都没有这个机会。因为我们手上的青春已经没剩多少了，我们活泼的说自己还是年... (展开)
351 14 72回应 收起
芜了♥薏全~ 2010-12-05 20:43:54

## 在那个时候，这真的不是一件小事

这篇影评可能有剧透

晚上打开QQ，初中群闪个不停，打开看见是同学们纷纷在里面“恭喜恭喜”，公告里写着“班长结婚了，大家来喝喜酒呀~”。我“哦”了一下，迅速地打了几个字“恭喜班长，结婚快乐！”，然后退出QQ。 其实什么话都说不出来，他结婚了，不是跟我。哦，不，应该这样说，他... (展开)
329 15 67回应 收起
川流 2010-12-12 14:46:19

## 这完全是给女生的建议嘛

看完电影强烈感受是，作为一个女的，你必须： 1.摘了你那苦逼的眼镜！！！ 2.卸了你的牙套！！！！！ 3.要变得白白净净的！！！！！！ 4.减肥啊变瘦啊果然身材才是王道！！！！！！！！ 5.穿衣服要合适！！！！！！！！拿一件大校服遮住自己是人生中最不给力的事情了！！... (展开)
211 18 67回应 收起
壳子 2010-12-05 05:04:30

## 你是唯一的灵感 u r the inspiration

这篇影评可能有剧透

当第一次看到这个电影名字的时候。我默默的对自己说。又是一部不用花费脑筋的狗血韩国电影。于是我直接跳过他。进入康熙来了的八卦世界。 结果晚上一个丝毫不爱看电影的朋友敲我。说她刚看完MARIO演的一部电影。出于对mario同学的热爱。我询问了片名。她用了一系列的修饰词。... (展开)
142 4 36回应 收起

> 更多影评 4441篇

添加新讨论

## 讨论区 · · · · · ·

现实中更多的是无疾而终 | 来自睡觉呢叫我干嘛 |  | 2022-11-21 14:48:20
为什么戏剧演出前阿亮学长说小水就算化妆了也是牙... | 来自橘子青未了 | 3 回应 | 2022-11-20 16:51:07
不知道为何评 分这么高 | 来自小脑斧 | 18 回应 | 2022-11-20 01:21:57
小彬学姐和阿亮真的在一起吗？？ | 来自一颗小丸子吖 | 4 回应 | 2022-11-09 06:11:10
是他们的故事，不是乌托邦 | 来自刘小真是三圣母 | 1 回应 | 2022-10-30 01:07:00

> 去这部影片的讨论区（全部283条）

## 关于《初恋这件小事》的问题 · · · · · · ( 全部20个 )

- 男主到底是在什么时候看上女主的？ 5人回答
- 初一时的小水和初三、当设计师后接受电台采访的小水是同一个演员吗？ 4人回答

> 全部20个问题

## 在哪儿看这部电影 · · · · · ·

- 咪咕视频 免费观看
- 爱奇艺视频 VIP免费观看
- 优酷视频 VIP免费观看
- 哔哩哔哩 VIP免费观看
- 西瓜视频 免费观看

## 以下片单推荐 · · · · · · ( 全部 )

- 【浪漫爱情轻喜】 (影志)
- ★豆瓣高分电影榜★ （中）8.5-8.3分 (影志)
- 2011第十四届上海国际电影节影片介绍大全 (妖灵妖)
- 【暗恋是一种病】 (影志)
- 十大必看泰国爱情电影 (CH23SE)

## 谁在看这部电影 · · · · · ·

- Cloris雷菁
  刚刚 看过
- 沉默是最好的
  刚刚 看过
- 墨央子
  5分钟前 看过

1880771人看过 / 131566人想看

订阅初恋这件小事的评论:
feed: rss 2.0